summaryrefslogtreecommitdiffstats
path: root/krdc/vnc/rfbproto.c
diff options
context:
space:
mode:
Diffstat (limited to 'krdc/vnc/rfbproto.c')
-rw-r--r--krdc/vnc/rfbproto.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/krdc/vnc/rfbproto.c b/krdc/vnc/rfbproto.c
index 371912a4..13676bb6 100644
--- a/krdc/vnc/rfbproto.c
+++ b/krdc/vnc/rfbproto.c
@@ -558,7 +558,7 @@ HandleSoftCursorSetImage(rfbSoftCursorSetImage *msg, rfbRectangle *rect)
/* framebuffer must be locked when calling this!!! */
static Bool
-PointerMove(unsigned int x, unsigned int y, unsigned int tqmask,
+PointerMove(unsigned int x, unsigned int y, unsigned int mask,
int ox, int oy, int ow, int oh)
{
int nx, ny, nw, nh;
@@ -585,7 +585,7 @@ PointerMove(unsigned int x, unsigned int y, unsigned int tqmask,
SyncScreenRegion(nx, ny, nw, nh);
}
- postMouseEvent(cursorX, cursorY, tqmask);
+ postMouseEvent(cursorX, cursorY, mask);
return True;
}
@@ -759,7 +759,7 @@ static Bool HandletqCursorShape(int xhot, int yhot, int width, int height, CARD3
if (width * height == 0)
return True;
/* Allocate memory for pixel data and temporary tqmask data. */
rcSource = malloc(width * height * bytesPerPixel);
if (rcSource == NULL)
@@ -830,7 +830,7 @@ static Bool HandletqCursorShape(int xhot, int yhot, int width, int height, CARD3
}
}
/* Read tqmask data. */
if (!ReadFromRFBServer((char*)rcMask, bytesMaskData)) {
free(rcSource);
@@ -759,7 +759,7 @@ static Bool HandletqCursorShape(int xhot, int yhot, int width, int height, CARD3
if (width * height == 0)
return True;
- /* Allocate memory for pixel data and temporary tqmask data. */
+ /* Allocate memory for pixel data and temporary mask data. */
rcSource = malloc(width * height * bytesPerPixel);
if (rcSource == NULL)
@@ -830,7 +830,7 @@ static Bool HandletqCursorShape(int xhot, int yhot, int width, int height, CARD3
}
}
- /* Read tqmask data. */
+ /* Read mask data. */
if (!ReadFromRFBServer((char*)rcMask, bytesMaskData)) {
free(rcSource);